=============================
Two Stage Euclidean Domains
=============================
-----------------------------
Algorithms for proving that class-number-one real quadratic fields are 2-stage euclidean, and to find continued fraction expansions in them.
-----------------------------


Installation
~~~~~~~~~~~~

To install the package use the following command::

   sage -pip install --user --upgrade twostage

If you rather install the cutting-edge version from the github repository (which is likely to be broken), then use the following command::

   sage -pip install --user --upgrade -v git+https://github.com/mmasdeu/twostage.git


